/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ElementRef, Renderer2 } from '@angular/core';
import { TreeItem, TreeItemLookup } from '@progress/kendo-angular-treeview';
import { PopupRef } from '@progress/kendo-angular-popup';
import { CheckedItem } from '../dropdowntrees/checked-state/checked-item';
import { DropDownSize } from './models/size';
import { DropDownRounded } from './models/rounded';
import { DropDownFillMode } from './models/fillmode';
import { ActionSheetComponent } from '@progress/kendo-angular-navigation';
import { AdaptiveSize } from '@progress/kendo-angular-utils';
/**
 * @hidden
 */
export declare const isPresent: Function;
/**
 * @hidden
 */
export declare const isNumber: Function;
/**
 * @hidden
 */
export declare const guid: Function;
/**
 * @hidden
 */
export declare const combineStr: Function;
/**
 * @hidden
 */
export declare const isWindowAvailable: Function;
/**
 * @hidden
 */
export declare const isArray: Function;
/**
 * @hidden
 */
export declare const isObject: Function;
/**
 * @hidden
 */
export declare const isEmptyString: (value: any) => boolean;
/**
 * @hidden
 */
export declare const resolveValuesInArray: Function;
/**
 * @hidden
 */
export declare const validateComplexValues: Function;
/**
 * @hidden
 */
export declare const resolveAllValues: Function;
/**
 * @hidden
 */
export declare const isObjectArray: Function;
/**
 * @hidden
 */
export declare const selectedIndices: Function;
/**
 * @hidden
 */
export declare const getter: (dataItem: any, field: string) => any;
/**
 * @hidden
 */
export declare const resolveValue: Function;
/**
 * @hidden
 */
export declare const sameCharsOnly: Function;
/**
 * @hidden
 */
export declare const shuffleData: Function;
/**
 * @hidden
 */
export declare const matchText: Function;
/**
 * @hidden
 */
export declare const elementFromPoint: (x: number, y: number) => Element;
/**
 * @hidden
 *
 * Checks whether the passed object has all of the listed properties.
 */
export declare const hasProps: (obj: object, props: string[]) => boolean;
/**
 * @hidden
 *
 * Checks whether an element is untouched by looking for the ng-untouched css class
 */
export declare const isUntouched: (element: HTMLElement) => boolean;
/**
 * @hidden
 */
export declare const noop: (_: any) => void;
/**
 * @hidden
 *
 * IE element `closest` polyfill.
 * https://developer.mozilla.org/en-US/docs/Web/API/Element/closest
 */
export declare const closest: (element: any, selector: string) => HTMLElement;
/**
 * @hidden
 *
 * Parses a provided value to its type 'number' representation.
 * If the parsed value (via Number(value)) is NaN, the provided default value is returned.
 * Uses 0 as default value if a second param is not provided.
 */
export declare const parseNumber: (num: any, defaultValue?: number) => number;
/**
 * @hidden
 *
 * Checks whether the passed target element is inside the provided host or popupRef.
 */
export declare const inDropDown: (host: ElementRef, target: HTMLElement, popupRef: PopupRef) => boolean;
/**
 * @hidden
 *
 * Calculates the hierarchical level of an item, based on the provided index.
 * The result level is zero-based (starts from 0).
 */
export declare const getHierarchicalItemLevel: (index: string) => number;
/**
 * @hidden
 *
 * Retrieves all descendant nodes' lookups which are currently registered in the provided lookup item as a flat array.
 */
export declare const fetchDescendentNodes: (lookup: any, filterExpression?: (lookup: TreeItem) => boolean) => TreeItemLookup[];
/**
 * @hidden
 *
 * Retrieves the correct value based on the item's level and the provided value field/s.
 * Used in the MultiSelectTree component.
 */
export declare const valueFrom: ({ dataItem, index, level }: CheckedItem, valueField: string | string[]) => any;
/**
 * @hidden
 * Returns the size class based on the component and size input.
 */
export declare const getSizeClass: (component: string, size: DropDownSize) => string;
/**
 * @hidden
 * Returns the rounded class based on the rounded input.
 */
export declare const getRoundedClass: (rounded: DropDownRounded) => string;
/**
 * @hidden
 * Return the fillMode class based on the component and fillMode input.
 */
export declare const getFillModeClass: (component: string, fillMode: DropDownFillMode) => string;
/**
 * @hidden
 */
export declare const filterAndMap: (arr: any[], predicate: (item: any) => boolean, mapper: (item: any) => any) => any[];
/**
 * @hidden
 *
 * Checks if input is Japanese IME
 */
export declare const isJapanese: (input: any) => boolean;
/**
 * @hidden
 */
export declare const isLetter: (text: string) => boolean;
/**
 * @hidden
 */
export declare const getTextField: (field: string | string[], level: number) => string;
/**
 * @hidden
 */
export declare const getSearchableItems: (treeViewId: string, element: HTMLElement) => {
    text: string;
    index: string;
}[];
/**
 * Specifies the adaptive rendering of the component.
 *
 * The supported values are:
 * * `none`&mdash;(default)
 * * `auto`
 */
export type AdaptiveMode = 'none' | 'auto';
/**
 * @hidden
 */
export declare const isTruthy: (value: any) => boolean;
/**
 * @hidden
 */
export declare const updateActionSheetAdaptiveAppearance: (actionSheet: ActionSheetComponent, windowSize: AdaptiveSize, renderer: Renderer2) => void;
/**
 * @hidden
 */
export declare const setListBoxAriaLabelledBy: (optionsList: any, element: ElementRef, renderer: Renderer2) => void;
/**
 * @hidden
 */
export declare const setActionSheetTitle: (element: ElementRef, actionSheetTitle: string) => string;
/**
 * @hidden
 */
export declare const animationDuration = 300;
