/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { NgModule } from '@angular/core';
import { KENDO_DROPDOWNS } from './directives';
import { PopupService } from '@progress/kendo-angular-popup';
import { KENDO_ADORNMENTS, KENDO_TOGGLEBUTTONTABSTOP, ResizeBatchService } from '@progress/kendo-angular-common';
import { IconsService } from '@progress/kendo-angular-icons';
import { DialogContainerService, DialogService, WindowContainerService, WindowService } from '@progress/kendo-angular-dialog';
import { AdaptiveService } from '@progress/kendo-angular-utils';
import * as i0 from "@angular/core";
import * as i1 from "./autocomplete/autocomplete.component";
import * as i2 from "./common/templates/fixed-group-template.directive";
import * as i3 from "./common/templates/footer-template.directive";
import * as i4 from "./common/templates/group-template.directive";
import * as i5 from "./common/templates/header-template.directive";
import * as i6 from "./common/templates/item-template.directive";
import * as i7 from "./common/templates/no-data-template.directive";
import * as i8 from "./common/filtering/filter.directive";
import * as i9 from "./common/localization/custom-messages.component";
import * as i10 from "@progress/kendo-angular-common";
import * as i11 from "./comboboxes/combobox.component";
import * as i12 from "./comboboxes/multicolumncombobox.component";
import * as i13 from "./comboboxes/combobox-column/combobox-column.component";
import * as i14 from "./comboboxes/combobox-column/column-header-template.directive";
import * as i15 from "./comboboxes/combobox-column/column-cell-template.directive";
import * as i16 from "./dropdownlist/dropdownlist.component";
import * as i17 from "./common/templates/value-template.directive";
import * as i18 from "./multiselect/multiselect.component";
import * as i19 from "./multiselect/summary-tag.directive";
import * as i20 from "./common/templates/custom-item-template.directive";
import * as i21 from "./common/templates/group-tag-template.directive";
import * as i22 from "./common/templates/tag-template.directive";
import * as i23 from "./dropdowntrees/dropdowntree.component";
import * as i24 from "./dropdowntrees/data-binding/dropdowntree/flat-binding.directive";
import * as i25 from "./dropdowntrees/data-binding/dropdowntree/hierarchy-binding.directive";
import * as i26 from "./dropdowntrees/expanded-state/expand.directive";
import * as i27 from "./dropdowntrees/templates/node-template.directive";
import * as i28 from "./dropdowntrees/multiselecttree.component";
import * as i29 from "./dropdowntrees/data-binding/multiselecttree/flat-binding.directive";
import * as i30 from "./dropdowntrees/data-binding/multiselecttree/hierarchy-binding.directive";
import * as i31 from "./dropdowntrees/summary-tag/summary-tag.directive";
// IMPORTANT: NgModule export kept for backwards compatibility
/**
 * Represents the [NgModule](link:site.data.urls.angular['ngmoduleapi'])
 * definition for the Dropdowns components.
 *
 * @example
 *
 * ```ts-no-run
 * // Import the Dropdowns module
 * import { DropDownsModule } from '@progress/kendo-angular-dropdowns';
 *
 * // The browser platform with a compiler
 * import { platformBrowserDynamic } from '@angular/platform-browser-dynamic';
 *
 * import { NgModule } from '@angular/core';
 *
 * // Import the app component
 * import { AppComponent } from './app.component';
 *
 * // Define the app module
 * _@NgModule({
 *     declarations: [AppComponent], // declare the app component
 *     imports:      [BrowserModule, DropDownsModule], // import the Dropdowns module
 *     bootstrap:    [AppComponent]
 * })
 * export class AppModule {}
 *
 * // Compile and launch the module
 * platformBrowserDynamic().bootstrapModule(AppModule);
 *
 * ```
 */
export class DropDownsModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: DropDownsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.2.12", ngImport: i0, type: DropDownsModule, imports: [i1.AutoCompleteComponent, i2.FixedGroupTemplateDirective, i3.FooterTemplateDirective, i4.GroupTemplateDirective, i5.HeaderTemplateDirective, i6.ItemTemplateDirective, i7.NoDataTemplateDirective, i8.FilterDirective, i9.CustomMessagesComponent, i10.SuffixTemplateDirective, i10.PrefixTemplateDirective, i10.SeparatorComponent, i11.ComboBoxComponent, i2.FixedGroupTemplateDirective, i3.FooterTemplateDirective, i4.GroupTemplateDirective, i5.HeaderTemplateDirective, i6.ItemTemplateDirective, i7.NoDataTemplateDirective, i8.FilterDirective, i9.CustomMessagesComponent, i10.SuffixTemplateDirective, i10.PrefixTemplateDirective, i10.SeparatorComponent, i10.ToggleButtonTabStopDirective, i12.MultiColumnComboBoxComponent, i13.ComboBoxColumnComponent, i14.ColumnHeaderTemplateDirective, i15.ColumnCellTemplateDirective, i2.FixedGroupTemplateDirective, i3.FooterTemplateDirective, i4.GroupTemplateDirective, i5.HeaderTemplateDirective, i6.ItemTemplateDirective, i7.NoDataTemplateDirective, i8.FilterDirective, i9.CustomMessagesComponent, i10.SuffixTemplateDirective, i10.PrefixTemplateDirective, i10.SeparatorComponent, i10.ToggleButtonTabStopDirective, i16.DropDownListComponent, i2.FixedGroupTemplateDirective, i3.FooterTemplateDirective, i4.GroupTemplateDirective, i5.HeaderTemplateDirective, i6.ItemTemplateDirective, i17.ValueTemplateDirective, i7.NoDataTemplateDirective, i8.FilterDirective, i9.CustomMessagesComponent, i18.MultiSelectComponent, i19.SummaryTagDirective, i20.CustomItemTemplateDirective, i2.FixedGroupTemplateDirective, i3.FooterTemplateDirective, i4.GroupTemplateDirective, i21.GroupTagTemplateDirective, i22.TagTemplateDirective, i5.HeaderTemplateDirective, i6.ItemTemplateDirective, i7.NoDataTemplateDirective, i8.FilterDirective, i9.CustomMessagesComponent, i10.SuffixTemplateDirective, i10.PrefixTemplateDirective, i10.SeparatorComponent, i23.DropDownTreeComponent, i24.DropDownTreeFlatBindingDirective, i25.DropDownTreeHierarchyBindingDirective, i26.DropDownTreesExpandDirective, i27.NodeTemplateDirective, i5.HeaderTemplateDirective, i3.FooterTemplateDirective, i17.ValueTemplateDirective, i7.NoDataTemplateDirective, i9.CustomMessagesComponent, i28.MultiSelectTreeComponent, i29.MultiSelectTreeFlatBindingDirective, i30.MultiSelectTreeHierarchyBindingDirective, i26.DropDownTreesExpandDirective, i27.NodeTemplateDirective, i31.MultiSelectTreeSummaryTagDirective, i21.GroupTagTemplateDirective, i22.TagTemplateDirective, i5.HeaderTemplateDirective, i3.FooterTemplateDirective, i17.ValueTemplateDirective, i7.NoDataTemplateDirective, i9.CustomMessagesComponent, i10.PrefixTemplateDirective, i10.SuffixTemplateDirective, i10.SeparatorComponent, i10.ToggleButtonTabStopDirective], exports: [i1.AutoCompleteComponent, i2.FixedGroupTemplateDirective, i3.FooterTemplateDirective, i4.GroupTemplateDirective, i5.HeaderTemplateDirective, i6.ItemTemplateDirective, i7.NoDataTemplateDirective, i8.FilterDirective, i9.CustomMessagesComponent, i10.SuffixTemplateDirective, i10.PrefixTemplateDirective, i10.SeparatorComponent, i11.ComboBoxComponent, i2.FixedGroupTemplateDirective, i3.FooterTemplateDirective, i4.GroupTemplateDirective, i5.HeaderTemplateDirective, i6.ItemTemplateDirective, i7.NoDataTemplateDirective, i8.FilterDirective, i9.CustomMessagesComponent, i10.SuffixTemplateDirective, i10.PrefixTemplateDirective, i10.SeparatorComponent, i10.ToggleButtonTabStopDirective, i12.MultiColumnComboBoxComponent, i13.ComboBoxColumnComponent, i14.ColumnHeaderTemplateDirective, i15.ColumnCellTemplateDirective, i2.FixedGroupTemplateDirective, i3.FooterTemplateDirective, i4.GroupTemplateDirective, i5.HeaderTemplateDirective, i6.ItemTemplateDirective, i7.NoDataTemplateDirective, i8.FilterDirective, i9.CustomMessagesComponent, i10.SuffixTemplateDirective, i10.PrefixTemplateDirective, i10.SeparatorComponent, i10.ToggleButtonTabStopDirective, i16.DropDownListComponent, i2.FixedGroupTemplateDirective, i3.FooterTemplateDirective, i4.GroupTemplateDirective, i5.HeaderTemplateDirective, i6.ItemTemplateDirective, i17.ValueTemplateDirective, i7.NoDataTemplateDirective, i8.FilterDirective, i9.CustomMessagesComponent, i18.MultiSelectComponent, i19.SummaryTagDirective, i20.CustomItemTemplateDirective, i2.FixedGroupTemplateDirective, i3.FooterTemplateDirective, i4.GroupTemplateDirective, i21.GroupTagTemplateDirective, i22.TagTemplateDirective, i5.HeaderTemplateDirective, i6.ItemTemplateDirective, i7.NoDataTemplateDirective, i8.FilterDirective, i9.CustomMessagesComponent, i10.SuffixTemplateDirective, i10.PrefixTemplateDirective, i10.SeparatorComponent, i23.DropDownTreeComponent, i24.DropDownTreeFlatBindingDirective, i25.DropDownTreeHierarchyBindingDirective, i26.DropDownTreesExpandDirective, i27.NodeTemplateDirective, i5.HeaderTemplateDirective, i3.FooterTemplateDirective, i17.ValueTemplateDirective, i7.NoDataTemplateDirective, i9.CustomMessagesComponent, i28.MultiSelectTreeComponent, i29.MultiSelectTreeFlatBindingDirective, i30.MultiSelectTreeHierarchyBindingDirective, i26.DropDownTreesExpandDirective, i27.NodeTemplateDirective, i31.MultiSelectTreeSummaryTagDirective, i21.GroupTagTemplateDirective, i22.TagTemplateDirective, i5.HeaderTemplateDirective, i3.FooterTemplateDirective, i17.ValueTemplateDirective, i7.NoDataTemplateDirective, i9.CustomMessagesComponent, i10.PrefixTemplateDirective, i10.SuffixTemplateDirective, i10.SeparatorComponent, i10.ToggleButtonTabStopDirective] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: DropDownsModule, providers: [PopupService, ResizeBatchService, IconsService, DialogContainerService, DialogService, WindowService, WindowContainerService, AdaptiveService], imports: [i1.AutoCompleteComponent, i10.SeparatorComponent, i11.ComboBoxComponent, i10.SeparatorComponent, i12.MultiColumnComboBoxComponent, i10.SeparatorComponent, i16.DropDownListComponent, i18.MultiSelectComponent, i10.SeparatorComponent, i23.DropDownTreeComponent, i28.MultiSelectTreeComponent, i10.SeparatorComponent] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: DropDownsModule, decorators: [{
            type: NgModule,
            args: [{
                    exports: [...KENDO_DROPDOWNS, ...KENDO_ADORNMENTS, ...KENDO_TOGGLEBUTTONTABSTOP],
                    imports: [...KENDO_DROPDOWNS, ...KENDO_ADORNMENTS, ...KENDO_TOGGLEBUTTONTABSTOP],
                    providers: [PopupService, ResizeBatchService, IconsService, DialogContainerService, DialogService, WindowService, WindowContainerService, AdaptiveService]
                }]
        }] });
